@@ -41,15 +41,9 @@ import pprint as pp
 from ..base_classes.tree import tree
 
 
-class Global:
+class __Global:
     """global var"""
 
-    def __new__(cls, *args, **kw):
-        if not hasattr(cls, '_instance'):
-            orig = super(Global, cls)
-            cls._instance = orig.__new__(cls, *args, **kw)
-        return cls._instance
-
     @property
     def glob_fn(self):
         return self._glob_fn
@@ -57,8 +51,12 @@ class Global:
     @property
     def local_fn(self):
         if self._local_fn is None:
-            sys.stderr.write("fatal: unable to read config file '.thexp/config.json': No such file or directory\n")
-            exit(1)
+            self._local_fn = self.check_local_dir_exists()
+            if self._local_fn is not None:
+                self._local_info = self.load(self.local_fn)
+            else:
+                sys.stderr.write("fatal: unable to read config file '.thexp/config.json': No such file or directory\n")
+                exit(1)
         return self._local_fn
 
     def __init__(self):
@@ -67,7 +65,7 @@ class Global:
         self._local_fn = self.check_local_dir_exists()
 
         self._glob_info = self.load(self.glob_fn)
-        self._local_info = self.load(self.local_fn)
+        self._local_info = self.load(self._local_fn)
 
     def list_config(self, glob=True, local=True):
         if glob:
@@ -102,7 +100,9 @@ class Global:
         while len(cur):
             if os.path.exists(os.path.join(cur, ".thexp")):
                 local_fn = os.path.join(cur, ".thexp", "config.json")
-                return local_fn
+                if local_fn != self.glob_fn:
+                    return local_fn
+
             ncur, _ = os.path.split(cur)
             if cur != ncur:
                 cur = ncur
@@ -124,16 +124,16 @@ class Global:
         with open(fn, "w", encoding="utf-8") as f:
             json.dump(obj, f, indent=2)
 
-    def __getattr__(self, item):
+    def __getitem__(self, item):
+        if item.startswith("_"):
+            raise AttributeError(item)
         if item in self._local_info:
             return self._local_info[item]
         elif item in self._glob_info:
             return self._glob_info[item]
         raise AttributeError(item)
 
-    def __getitem__(self, item):
-        item = str(item)
-        return self.__getattr__(item)
+globs = __Global()
 
 
 class Experiment:
@@ -159,7 +159,7 @@ class Experiment:
             exps_dir = os.path.join(main_dir, "experiment")
         self.exp_dir = exps_dir
         os.makedirs(self.exp_dir, exist_ok=True)
-        self.glob = Global()
+        self.glob = globs
         self.db = PickleDB(self.dbfile, auto_dump=True)
 
         self.event_handler = ExperimentEventHandler()
@@ -409,8 +409,4 @@ class ExperimentViewer:
         return self.__db.get(datekey)
 
     def exp_code(self, datekey):
-        return self.__db.get(datekey)["snap"]
-
-
-if __name__ == '__main__':
-    pass
+        return self.__db.get(datekey)["snap"]
\ No newline at end of file
